/* OGMRip - A library for DVD ripping and encoding
 * Copyright (C) 2004-2005 Olivier Rolland <billl@esil.univ-mrs.fr>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef __OGMRIP_CONTAINER_H__
#define __OGMRIP_CONTAINER_H__

#include <ogmsp-bin.h>

G_BEGIN_DECLS

#define OGMRIP_TYPE_CONTAINER           (ogmrip_container_get_type ())
#define OGMRIP_CONTAINER(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), OGMRIP_TYPE_CONTAINER, OGMRipContainer))
#define OGMRIP_CONTAINER_CLASS(klass)   (G_TYPE_CHECK_CLASS_CAST ((klass), OGMRIP_TYPE_CONTAINER, OGMRipContainerClass))
#define OGMRIP_IS_CONTAINER(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OGMRIP_TYPE_CONTAINER))
#define OGMRIP_IS_CONTAINER_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((klass), OGMRIP_TYPE_CONTAINER))
#define OGMRIP_CONTAINER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OGMRIP_TYPE_CONTAINER, OGMRipContainerClass))

typedef struct _OGMRipContainer      OGMRipContainer;
typedef struct _OGMRipContainerPriv  OGMRipContainerPriv;
typedef struct _OGMRipContainerClass OGMRipContainerClass;

typedef void (* OGMRipContainerFunc) (OGMRipContainer *container,
                                      const gchar     *input,
                                      gint            language,
                                      gpointer        user_data);

struct _OGMRipContainer
{
  OGMSpBin parent_instance;

  OGMRipContainerPriv *priv;
};

struct _OGMRipContainerClass
{
  OGMSpBinClass parent_class;

  gint64 (* get_overhead_size) (OGMRipContainer *container,
                                guint64         size,
                                gulong          length);
};

GType   ogmrip_container_get_type            (void);

void    ogmrip_container_set_target_size     (OGMRipContainer     *container,
                                              guint               tnumber,
                                              guint               tsize);
gint    ogmrip_container_get_tnumber         (OGMRipContainer     *container);
gint    ogmrip_container_get_tsize           (OGMRipContainer     *container);

G_CONST_RETURN
gchar * ogmrip_container_get_output          (OGMRipContainer     *container);
void    ogmrip_container_set_output          (OGMRipContainer     *container,
                                              const gchar         *output);
G_CONST_RETURN
gchar * ogmrip_container_get_title           (OGMRipContainer     *container);
void    ogmrip_container_set_title           (OGMRipContainer     *container,
                                              const gchar         *title);
G_CONST_RETURN
gchar * ogmrip_container_get_video           (OGMRipContainer     *container);
void    ogmrip_container_set_video           (OGMRipContainer     *container,
                                              const gchar         *input);

void     ogmrip_container_add_audio          (OGMRipContainer     *container,
                                              const gchar         *input,
                                              gint                language);
GList *  ogmrip_container_get_audio          (OGMRipContainer     *container);
gint     ogmrip_container_count_audio        (OGMRipContainer     *container);

void     ogmrip_container_add_chapters       (OGMRipContainer     *container,
                                              const gchar         *input,
                                              gint                language);
GList *  ogmrip_container_get_chapters       (OGMRipContainer     *container);
gint     ogmrip_container_count_chapters     (OGMRipContainer     *container);

void     ogmrip_container_add_subp           (OGMRipContainer     *container,
                                              const gchar         *input,
                                              gint                language);
GList *  ogmrip_container_get_subp           (OGMRipContainer     *container);
gint     ogmrip_container_count_subp         (OGMRipContainer     *container);

void    ogmrip_container_foreach_audio       (OGMRipContainer     *container, 
                                              OGMRipContainerFunc func, 
                                              gpointer            data);
void    ogmrip_container_foreach_chapter     (OGMRipContainer     *container, 
                                              OGMRipContainerFunc func, 
                                              gpointer            data);
void    ogmrip_container_foreach_subp        (OGMRipContainer     *container, 
                                              OGMRipContainerFunc func, 
                                              gpointer            data);

void    ogmrip_container_set_unlink_on_unref (OGMRipContainer     *container,
                                              gboolean            do_unlink);

gint64  ogmrip_container_get_nonvideo_size   (OGMRipContainer     *container);
gint64  ogmrip_container_get_overhead_size   (OGMRipContainer     *container,
                                              guint64             size,
                                              gulong              length);

G_END_DECLS

#endif /* __OGMRIP_CONTAINER_H__ */

